# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
STEPSelections module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stepselections.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _STEPSelections
else:
    import _STEPSelections

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _STEPSelections.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _STEPSelections.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _STEPSelections.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _STEPSelections.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _STEPSelections.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _STEPSelections.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _STEPSelections.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _STEPSelections.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _STEPSelections.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _STEPSelections.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _STEPSelections.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _STEPSelections.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _STEPSelections.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _STEPSelections.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _STEPSelections.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _STEPSelections.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _STEPSelections.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _STEPSelections:
_STEPSelections.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _STEPSelections.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepRepr
import OCC.Core.StepBasic
import OCC.Core.IFSelect
import OCC.Core.XSControl
import OCC.Core.Transfer
import OCC.Core.TopTools
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_STEPSelections_AssemblyComponent_Create() -> "opencascade::handle< STEPSelections_AssemblyComponent >":
    return _STEPSelections.Handle_STEPSelections_AssemblyComponent_Create()

def Handle_STEPSelections_AssemblyComponent_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_AssemblyComponent >":
    return _STEPSelections.Handle_STEPSelections_AssemblyComponent_DownCast(t)

def Handle_STEPSelections_AssemblyComponent_IsNull(t: "opencascade::handle< STEPSelections_AssemblyComponent > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_AssemblyComponent_IsNull(t)

def Handle_STEPSelections_AssemblyLink_Create() -> "opencascade::handle< STEPSelections_AssemblyLink >":
    return _STEPSelections.Handle_STEPSelections_AssemblyLink_Create()

def Handle_STEPSelections_AssemblyLink_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_AssemblyLink >":
    return _STEPSelections.Handle_STEPSelections_AssemblyLink_DownCast(t)

def Handle_STEPSelections_AssemblyLink_IsNull(t: "opencascade::handle< STEPSelections_AssemblyLink > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_AssemblyLink_IsNull(t)

def Handle_STEPSelections_SelectAssembly_Create() -> "opencascade::handle< STEPSelections_SelectAssembly >":
    return _STEPSelections.Handle_STEPSelections_SelectAssembly_Create()

def Handle_STEPSelections_SelectAssembly_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_SelectAssembly >":
    return _STEPSelections.Handle_STEPSelections_SelectAssembly_DownCast(t)

def Handle_STEPSelections_SelectAssembly_IsNull(t: "opencascade::handle< STEPSelections_SelectAssembly > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_SelectAssembly_IsNull(t)

def Handle_STEPSelections_SelectDerived_Create() -> "opencascade::handle< STEPSelections_SelectDerived >":
    return _STEPSelections.Handle_STEPSelections_SelectDerived_Create()

def Handle_STEPSelections_SelectDerived_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_SelectDerived >":
    return _STEPSelections.Handle_STEPSelections_SelectDerived_DownCast(t)

def Handle_STEPSelections_SelectDerived_IsNull(t: "opencascade::handle< STEPSelections_SelectDerived > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_SelectDerived_IsNull(t)

def Handle_STEPSelections_SelectFaces_Create() -> "opencascade::handle< STEPSelections_SelectFaces >":
    return _STEPSelections.Handle_STEPSelections_SelectFaces_Create()

def Handle_STEPSelections_SelectFaces_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_SelectFaces >":
    return _STEPSelections.Handle_STEPSelections_SelectFaces_DownCast(t)

def Handle_STEPSelections_SelectFaces_IsNull(t: "opencascade::handle< STEPSelections_SelectFaces > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_SelectFaces_IsNull(t)

def Handle_STEPSelections_SelectForTransfer_Create() -> "opencascade::handle< STEPSelections_SelectForTransfer >":
    return _STEPSelections.Handle_STEPSelections_SelectForTransfer_Create()

def Handle_STEPSelections_SelectForTransfer_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_SelectForTransfer >":
    return _STEPSelections.Handle_STEPSelections_SelectForTransfer_DownCast(t)

def Handle_STEPSelections_SelectForTransfer_IsNull(t: "opencascade::handle< STEPSelections_SelectForTransfer > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_SelectForTransfer_IsNull(t)

def Handle_STEPSelections_SelectGSCurves_Create() -> "opencascade::handle< STEPSelections_SelectGSCurves >":
    return _STEPSelections.Handle_STEPSelections_SelectGSCurves_Create()

def Handle_STEPSelections_SelectGSCurves_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_SelectGSCurves >":
    return _STEPSelections.Handle_STEPSelections_SelectGSCurves_DownCast(t)

def Handle_STEPSelections_SelectGSCurves_IsNull(t: "opencascade::handle< STEPSelections_SelectGSCurves > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_SelectGSCurves_IsNull(t)

def Handle_STEPSelections_SelectInstances_Create() -> "opencascade::handle< STEPSelections_SelectInstances >":
    return _STEPSelections.Handle_STEPSelections_SelectInstances_Create()

def Handle_STEPSelections_SelectInstances_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_SelectInstances >":
    return _STEPSelections.Handle_STEPSelections_SelectInstances_DownCast(t)

def Handle_STEPSelections_SelectInstances_IsNull(t: "opencascade::handle< STEPSelections_SelectInstances > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_SelectInstances_IsNull(t)

def Handle_STEPSelections_HSequenceOfAssemblyLink_Create() -> "opencascade::handle< STEPSelections_HSequenceOfAssemblyLink >":
    return _STEPSelections.Handle_STEPSelections_HSequenceOfAssemblyLink_Create()

def Handle_STEPSelections_HSequenceOfAssemblyLink_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< STEPSelections_HSequenceOfAssemblyLink >":
    return _STEPSelections.Handle_STEPSelections_HSequenceOfAssemblyLink_DownCast(t)

def Handle_STEPSelections_HSequenceOfAssemblyLink_IsNull(t: "opencascade::handle< STEPSelections_HSequenceOfAssemblyLink > const &") -> "bool":
    return _STEPSelections.Handle_STEPSelections_HSequenceOfAssemblyLink_IsNull(t)
class STEPSelections_SequenceOfAssemblyComponent(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyComponent > >::iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyComponent > >::iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyComponent > >::const_iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyComponent > >::const_iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_cend(self)

    def __init__(self, *args):
        _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_swiginit(self, _STEPSelections.new_STEPSelections_SequenceOfAssemblyComponent(*args))

    def Size(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Size(self)

    def Length(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_IsEmpty(self)

    def Reverse(self) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Clear(self, theAllocator)

    def Assign(self, theOther: "STEPSelections_SequenceOfAssemblyComponent") -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyComponent > > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Assign(self, theOther)

    def Set(self, theOther: "STEPSelections_SequenceOfAssemblyComponent") -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyComponent > > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "STEPSelections_SequenceOfAssemblyComponent") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< STEPSelections_AssemblyComponent > const &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_First(self)

    def ChangeFirst(self) -> "opencascade::handle< STEPSelections_AssemblyComponent > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< STEPSelections_AssemblyComponent > const &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Last(self)

    def ChangeLast(self) -> "opencascade::handle< STEPSelections_AssemblyComponent > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< STEPSelections_AssemblyComponent > const &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< STEPSelections_AssemblyComponent > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< STEPSelections_AssemblyComponent > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< STEPSelections_AssemblyComponent > const &") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SequenceOfAssemblyComponent

    def __len__(self):
        return self.Size()


# Register STEPSelections_SequenceOfAssemblyComponent in _STEPSelections:
_STEPSelections.STEPSelections_SequenceOfAssemblyComponent_swigregister(STEPSelections_SequenceOfAssemblyComponent)

def STEPSelections_SequenceOfAssemblyComponent_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _STEPSelections.STEPSelections_SequenceOfAssemblyComponent_delNode(theNode, theAl)

class STEPSelections_SequenceOfAssemblyLink(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyLink > >::iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyLink > >::iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyLink > >::const_iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyLink > >::const_iterator":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_cend(self)

    def __init__(self, *args):
        _STEPSelections.STEPSelections_SequenceOfAssemblyLink_swiginit(self, _STEPSelections.new_STEPSelections_SequenceOfAssemblyLink(*args))

    def Size(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Size(self)

    def Length(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_IsEmpty(self)

    def Reverse(self) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Clear(self, theAllocator)

    def Assign(self, theOther: "STEPSelections_SequenceOfAssemblyLink") -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyLink > > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Assign(self, theOther)

    def Set(self, theOther: "STEPSelections_SequenceOfAssemblyLink") -> "NCollection_Sequence< opencascade::handle< STEPSelections_AssemblyLink > > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "STEPSelections_SequenceOfAssemblyLink") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< STEPSelections_AssemblyLink > const &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_First(self)

    def ChangeFirst(self) -> "opencascade::handle< STEPSelections_AssemblyLink > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< STEPSelections_AssemblyLink > const &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Last(self)

    def ChangeLast(self) -> "opencascade::handle< STEPSelections_AssemblyLink > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< STEPSelections_AssemblyLink > const &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< STEPSelections_AssemblyLink > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< STEPSelections_AssemblyLink > &":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< STEPSelections_AssemblyLink > const &") -> "void":
        return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SequenceOfAssemblyLink

    def __len__(self):
        return self.Size()


# Register STEPSelections_SequenceOfAssemblyLink in _STEPSelections:
_STEPSelections.STEPSelections_SequenceOfAssemblyLink_swigregister(STEPSelections_SequenceOfAssemblyLink)

def STEPSelections_SequenceOfAssemblyLink_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _STEPSelections.STEPSelections_SequenceOfAssemblyLink_delNode(theNode, theAl)

class STEPSelections_AssemblyComponent(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        sdr: StepShape_ShapeDefinitionRepresentation
        list: STEPSelections_HSequenceOfAssemblyLink

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_AssemblyComponent_swiginit(self, _STEPSelections.new_STEPSelections_AssemblyComponent(*args))

    def GetList(self, *args) -> "opencascade::handle< STEPSelections_HSequenceOfAssemblyLink >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<STEPSelections_HSequenceOfAssemblyLink>

        """
        return _STEPSelections.STEPSelections_AssemblyComponent_GetList(self, *args)

    def GetSDR(self, *args) -> "opencascade::handle< StepShape_ShapeDefinitionRepresentation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepShape_ShapeDefinitionRepresentation>

        """
        return _STEPSelections.STEPSelections_AssemblyComponent_GetSDR(self, *args)

    def SetList(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        list: STEPSelections_HSequenceOfAssemblyLink

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_AssemblyComponent_SetList(self, *args)

    def SetSDR(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        sdr: StepShape_ShapeDefinitionRepresentation

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_AssemblyComponent_SetSDR(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_AssemblyComponent_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_AssemblyComponent

# Register STEPSelections_AssemblyComponent in _STEPSelections:
_STEPSelections.STEPSelections_AssemblyComponent_swigregister(STEPSelections_AssemblyComponent)

class STEPSelections_AssemblyExplorer(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        G: Interface_Graph

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_AssemblyExplorer_swiginit(self, _STEPSelections.new_STEPSelections_AssemblyExplorer(*args))

    def DumpToString(self) -> "std::string":
        r"""DumpToString(STEPSelections_AssemblyExplorer self) -> std::string"""
        return _STEPSelections.STEPSelections_AssemblyExplorer_DumpToString(self)

    def FillListWithGraph(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        cmp: STEPSelections_AssemblyComponent

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_AssemblyExplorer_FillListWithGraph(self, *args)

    def FindItemWithNAUO(self, *args) -> "opencascade::handle< Standard_Transient >":
        r"""
        No available documentation.

        Parameters
        ----------
        nauo: StepRepr_NextAssemblyUsageOccurrence

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _STEPSelections.STEPSelections_AssemblyExplorer_FindItemWithNAUO(self, *args)

    def FindSDRWithProduct(self, *args) -> "opencascade::handle< StepShape_ShapeDefinitionRepresentation >":
        r"""
        No available documentation.

        Parameters
        ----------
        product: StepBasic_ProductDefinition

        Returns
        -------
        opencascade::handle<StepShape_ShapeDefinitionRepresentation>

        """
        return _STEPSelections.STEPSelections_AssemblyExplorer_FindSDRWithProduct(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        G: Interface_Graph

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_AssemblyExplorer_Init(self, *args)

    def NbAssemblies(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of root assemblies;.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_AssemblyExplorer_NbAssemblies(self, *args)

    def Root(self, *args) -> "opencascade::handle< STEPSelections_AssemblyComponent >":
        r"""
        Returns root of assenbly by its rank;.

        Parameters
        ----------
        rank: int,optional
        	default value is 1

        Returns
        -------
        opencascade::handle<STEPSelections_AssemblyComponent>

        """
        return _STEPSelections.STEPSelections_AssemblyExplorer_Root(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_AssemblyExplorer

# Register STEPSelections_AssemblyExplorer in _STEPSelections:
_STEPSelections.STEPSelections_AssemblyExplorer_swigregister(STEPSelections_AssemblyExplorer)

class STEPSelections_AssemblyLink(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        nauo: StepRepr_NextAssemblyUsageOccurrence
        item: Standard_Transient
        part: STEPSelections_AssemblyComponent

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_AssemblyLink_swiginit(self, _STEPSelections.new_STEPSelections_AssemblyLink(*args))

    def GetComponent(self, *args) -> "opencascade::handle< STEPSelections_AssemblyComponent >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<STEPSelections_AssemblyComponent>

        """
        return _STEPSelections.STEPSelections_AssemblyLink_GetComponent(self, *args)

    def GetItem(self, *args) -> "opencascade::handle< Standard_Transient >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _STEPSelections.STEPSelections_AssemblyLink_GetItem(self, *args)

    def GetNAUO(self, *args) -> "opencascade::handle< StepRepr_NextAssemblyUsageOccurrence >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_NextAssemblyUsageOccurrence>

        """
        return _STEPSelections.STEPSelections_AssemblyLink_GetNAUO(self, *args)

    def SetComponent(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        part: STEPSelections_AssemblyComponent

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_AssemblyLink_SetComponent(self, *args)

    def SetItem(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        item: Standard_Transient

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_AssemblyLink_SetItem(self, *args)

    def SetNAUO(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        nauo: StepRepr_NextAssemblyUsageOccurrence

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_AssemblyLink_SetNAUO(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_AssemblyLink_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_AssemblyLink

# Register STEPSelections_AssemblyLink in _STEPSelections:
_STEPSelections.STEPSelections_AssemblyLink_swigregister(STEPSelections_AssemblyLink)

class STEPSelections_Counter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_Counter_swiginit(self, _STEPSelections.new_STEPSelections_Counter(*args))

    def Clear(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_Counter_Clear(self, *args)

    def Count(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        graph: Interface_Graph
        start: Standard_Transient

        Returns
        -------
        None

        """
        return _STEPSelections.STEPSelections_Counter_Count(self, *args)

    def NbInstancesOfEdges(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbInstancesOfEdges(self, *args)

    def NbInstancesOfFaces(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbInstancesOfFaces(self, *args)

    def NbInstancesOfShells(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbInstancesOfShells(self, *args)

    def NbInstancesOfSolids(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbInstancesOfSolids(self, *args)

    def NbInstancesOfWires(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbInstancesOfWires(self, *args)

    def NbSourceEdges(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbSourceEdges(self, *args)

    def NbSourceFaces(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbSourceFaces(self, *args)

    def NbSourceShells(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbSourceShells(self, *args)

    def NbSourceSolids(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbSourceSolids(self, *args)

    def NbSourceWires(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _STEPSelections.STEPSelections_Counter_NbSourceWires(self, *args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def POP(self):
    	pass

    @methodnotwrapped
    def POP2(self):
    	pass

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_Counter

# Register STEPSelections_Counter in _STEPSelections:
_STEPSelections.STEPSelections_Counter_swigregister(STEPSelections_Counter)

class STEPSelections_SelectAssembly(OCC.Core.IFSelect.IFSelect_SelectExplore):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_SelectAssembly_swiginit(self, _STEPSelections.new_STEPSelections_SelectAssembly(*args))


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_SelectAssembly_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SelectAssembly

# Register STEPSelections_SelectAssembly in _STEPSelections:
_STEPSelections.STEPSelections_SelectAssembly_swigregister(STEPSelections_SelectAssembly)

class STEPSelections_SelectDerived(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_SelectDerived_swiginit(self, _STEPSelections.new_STEPSelections_SelectDerived(*args))

    def Matches(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: Standard_Transient
        model: Interface_InterfaceModel
        text: TCollection_AsciiString
        exact: bool

        Returns
        -------
        bool

        """
        return _STEPSelections.STEPSelections_SelectDerived_Matches(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_SelectDerived_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SelectDerived

# Register STEPSelections_SelectDerived in _STEPSelections:
_STEPSelections.STEPSelections_SelectDerived_swigregister(STEPSelections_SelectDerived)

class STEPSelections_SelectFaces(OCC.Core.IFSelect.IFSelect_SelectExplore):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_SelectFaces_swiginit(self, _STEPSelections.new_STEPSelections_SelectFaces(*args))


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_SelectFaces_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SelectFaces

# Register STEPSelections_SelectFaces in _STEPSelections:
_STEPSelections.STEPSelections_SelectFaces_swigregister(STEPSelections_SelectFaces)

class STEPSelections_SelectForTransfer(OCC.Core.XSControl.XSControl_SelectForTransfer):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        TR: XSControl_TransferReader

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_SelectForTransfer_swiginit(self, _STEPSelections.new_STEPSelections_SelectForTransfer(*args))


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_SelectForTransfer_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SelectForTransfer

# Register STEPSelections_SelectForTransfer in _STEPSelections:
_STEPSelections.STEPSelections_SelectForTransfer_swigregister(STEPSelections_SelectForTransfer)

class STEPSelections_SelectGSCurves(OCC.Core.IFSelect.IFSelect_SelectExplore):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_SelectGSCurves_swiginit(self, _STEPSelections.new_STEPSelections_SelectGSCurves(*args))


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_SelectGSCurves_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SelectGSCurves

# Register STEPSelections_SelectGSCurves in _STEPSelections:
_STEPSelections.STEPSelections_SelectGSCurves_swigregister(STEPSelections_SelectGSCurves)

class STEPSelections_SelectInstances(OCC.Core.IFSelect.IFSelect_SelectExplore):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _STEPSelections.STEPSelections_SelectInstances_swiginit(self, _STEPSelections.new_STEPSelections_SelectInstances(*args))


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_SelectInstances_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_SelectInstances

# Register STEPSelections_SelectInstances in _STEPSelections:
_STEPSelections.STEPSelections_SelectInstances_swigregister(STEPSelections_SelectInstances)

class STEPSelections_HSequenceOfAssemblyLink(STEPSelections_SequenceOfAssemblyLink, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _STEPSelections.STEPSelections_HSequenceOfAssemblyLink_swiginit(self, _STEPSelections.new_STEPSelections_HSequenceOfAssemblyLink(*args))

    def Sequence(self) -> "STEPSelections_SequenceOfAssemblyLink const &":
        return _STEPSelections.STEPSelections_HSequenceOfAssemblyLink_Sequence(self)

    def Append(self, *args) -> "void":
        return _STEPSelections.STEPSelections_HSequenceOfAssemblyLink_Append(self, *args)

    def ChangeSequence(self) -> "STEPSelections_SequenceOfAssemblyLink &":
        return _STEPSelections.STEPSelections_HSequenceOfAssemblyLink_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_STEPSelections_HSequenceOfAssemblyLink_DownCast(t)

    __swig_destroy__ = _STEPSelections.delete_STEPSelections_HSequenceOfAssemblyLink

# Register STEPSelections_HSequenceOfAssemblyLink in _STEPSelections:
_STEPSelections.STEPSelections_HSequenceOfAssemblyLink_swigregister(STEPSelections_HSequenceOfAssemblyLink)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.TopAbs import *
from OCC.Core.gp import *
from OCC.Core.IntRes2d import *
from OCC.Core.Geom2dInt import *


class BRepClass_Edge:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, E: TopoDS_Edge, F: TopoDS_Face) -> None: ...
	@overload
	def Edge(self) -> TopoDS_Edge: ...
	@overload
	def Edge(self) -> TopoDS_Edge: ...
	@overload
	def Face(self) -> TopoDS_Face: ...
	@overload
	def Face(self) -> TopoDS_Face: ...

class BRepClass_FClass2dOfFClassifier:
	def __init__(self) -> None: ...
	def ClosestIntersection(self) -> int: ...
	def Compare(self, E: BRepClass_Edge, Or: TopAbs_Orientation) -> None: ...
	def Intersector(self) -> BRepClass_Intersector: ...
	def IsHeadOrEnd(self) -> bool: ...
	def Parameter(self) -> float: ...
	def Reset(self, L: gp_Lin2d, P: float, Tol: float) -> None: ...
	def State(self) -> TopAbs_State: ...

class BRepClass_FClassifier:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: BRepClass_FaceExplorer, P: gp_Pnt2d, Tol: float) -> None: ...
	def Edge(self) -> BRepClass_Edge: ...
	def EdgeParameter(self) -> float: ...
	def NoWires(self) -> bool: ...
	def Perform(self, F: BRepClass_FaceExplorer, P: gp_Pnt2d, Tol: float) -> None: ...
	def Position(self) -> IntRes2d_Position: ...
	def Rejected(self) -> bool: ...
	def State(self) -> TopAbs_State: ...

class BRepClass_FaceExplorer:
	def __init__(self, F: TopoDS_Face) -> None: ...
	def CheckPoint(self, thePoint: gp_Pnt2d) -> bool: ...
	def CurrentEdge(self, E: BRepClass_Edge, Or: TopAbs_Orientation) -> None: ...
	def InitEdges(self) -> None: ...
	def InitWires(self) -> None: ...
	def MoreEdges(self) -> bool: ...
	def MoreWires(self) -> bool: ...
	def NextEdge(self) -> None: ...
	def NextWire(self) -> None: ...
	def OtherSegment(self, P: gp_Pnt2d, L: gp_Lin2d) -> Tuple[bool, float]: ...
	def Reject(self, P: gp_Pnt2d) -> bool: ...
	def RejectEdge(self, L: gp_Lin2d, Par: float) -> bool: ...
	def RejectWire(self, L: gp_Lin2d, Par: float) -> bool: ...
	def Segment(self, P: gp_Pnt2d, L: gp_Lin2d) -> Tuple[bool, float]: ...

class BRepClass_FacePassiveClassifier:
	def __init__(self) -> None: ...
	def ClosestIntersection(self) -> int: ...
	def Compare(self, E: BRepClass_Edge, Or: TopAbs_Orientation) -> None: ...
	def Intersector(self) -> BRepClass_Intersector: ...
	def IsHeadOrEnd(self) -> bool: ...
	def Parameter(self) -> float: ...
	def Reset(self, L: gp_Lin2d, P: float, Tol: float) -> None: ...
	def State(self) -> TopAbs_State: ...

class BRepClass_Intersector(Geom2dInt_IntConicCurveOfGInter):
	def __init__(self) -> None: ...
	def LocalGeometry(self, E: BRepClass_Edge, U: float, T: gp_Dir2d, N: gp_Dir2d) -> float: ...
	def Perform(self, L: gp_Lin2d, P: float, Tol: float, E: BRepClass_Edge) -> None: ...

class BRepClass_FaceClassifier(BRepClass_FClassifier):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: BRepClass_FaceExplorer, P: gp_Pnt2d, Tol: float) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, P: gp_Pnt2d, Tol: float) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, P: gp_Pnt, Tol: float) -> None: ...
	@overload
	def Perform(self, F: TopoDS_Face, P: gp_Pnt2d, Tol: float) -> None: ...
	@overload
	def Perform(self, F: TopoDS_Face, P: gp_Pnt, Tol: float) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.math import *
from OCC.Core.TColgp import *
from OCC.Core.gp import *
from OCC.Core.GeomAbs import *


class BSplCLib_MultDistribution(IntEnum):
	BSplCLib_NonConstant: int = ...
	BSplCLib_Constant: int = ...
	BSplCLib_QuasiConstant: int = ...
BSplCLib_NonConstant = BSplCLib_MultDistribution.BSplCLib_NonConstant
BSplCLib_Constant = BSplCLib_MultDistribution.BSplCLib_Constant
BSplCLib_QuasiConstant = BSplCLib_MultDistribution.BSplCLib_QuasiConstant

class BSplCLib_KnotDistribution(IntEnum):
	BSplCLib_NonUniform: int = ...
	BSplCLib_Uniform: int = ...
BSplCLib_NonUniform = BSplCLib_KnotDistribution.BSplCLib_NonUniform
BSplCLib_Uniform = BSplCLib_KnotDistribution.BSplCLib_Uniform

class bsplclib:
	@staticmethod
	def AntiBoorScheme(U: float, Degree: int, Dimension: int, Depth: int, Length: int, Tolerance: float) -> Tuple[bool, float, float]: ...
	@staticmethod
	def Bohm(U: float, Degree: int, N: int, Dimension: int) -> Tuple[float, float]: ...
	@staticmethod
	def BoorIndex(Index: int, Length: int, Depth: int) -> int: ...
	@staticmethod
	def BoorScheme(U: float, Degree: int, Dimension: int, Depth: int, Length: int) -> Tuple[float, float]: ...
	@staticmethod
	def BuildBSpMatrix(Parameters: TColStd_Array1OfReal, OrderArray: TColStd_Array1OfInteger, FlatKnots: TColStd_Array1OfReal, Degree: int, Matrix: math_Matrix) -> Tuple[int, int, int]: ...
	@staticmethod
	def BuildBoor(Index: int, Length: int, Dimension: int, Poles: TColStd_Array1OfReal) -> float: ...
	@overload
	@staticmethod
	def BuildCache(U: float, InverseOfSpanDomain: float, PeriodicFlag: bool, Degree: int, FlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, CachePoles: TColgp_Array1OfPnt, CacheWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def BuildCache(U: float, InverseOfSpanDomain: float, PeriodicFlag: bool, Degree: int, FlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, CachePoles: TColgp_Array1OfPnt2d, CacheWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def BuildCache(theParameter: float, theSpanDomain: float, thePeriodicFlag: bool, theDegree: int, theSpanIndex: int, theFlatKnots: TColStd_Array1OfReal, thePoles: TColgp_Array1OfPnt, theWeights: TColStd_Array1OfReal, theCacheArray: TColStd_Array2OfReal) -> None: ...
	@overload
	@staticmethod
	def BuildCache(theParameter: float, theSpanDomain: float, thePeriodicFlag: bool, theDegree: int, theSpanIndex: int, theFlatKnots: TColStd_Array1OfReal, thePoles: TColgp_Array1OfPnt2d, theWeights: TColStd_Array1OfReal, theCacheArray: TColStd_Array2OfReal) -> None: ...
	@overload
	@staticmethod
	def BuildEval(Degree: int, Index: int, Poles: TColStd_Array1OfReal, Weights: TColStd_Array1OfReal) -> float: ...
	@overload
	@staticmethod
	def BuildEval(Degree: int, Index: int, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal) -> float: ...
	@overload
	@staticmethod
	def BuildEval(Degree: int, Index: int, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal) -> float: ...
	@staticmethod
	def BuildKnots(Degree: int, Index: int, Periodic: bool, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> float: ...
	@staticmethod
	def BuildSchoenbergPoints(Degree: int, FlatKnots: TColStd_Array1OfReal, Parameters: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def CacheD0(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def CacheD0(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d) -> None: ...
	@overload
	@staticmethod
	def CacheD1(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt, Vec: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CacheD1(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d, Vec: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CacheD2(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt, Vec1: gp_Vec, Vec2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CacheD2(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d, Vec1: gp_Vec2d, Vec2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CacheD3(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt, Vec1: gp_Vec, Vec2: gp_Vec, Vec3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CacheD3(U: float, Degree: int, CacheParameter: float, SpanLenght: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d, Vec1: gp_Vec2d, Vec2: gp_Vec2d, Vec3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CoefsD0(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def CoefsD0(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d) -> None: ...
	@overload
	@staticmethod
	def CoefsD1(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt, Vec: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CoefsD1(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d, Vec: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CoefsD2(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt, Vec1: gp_Vec, Vec2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CoefsD2(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d, Vec1: gp_Vec2d, Vec2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CoefsD3(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt, Vec1: gp_Vec, Vec2: gp_Vec, Vec3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CoefsD3(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d, Vec1: gp_Vec2d, Vec2: gp_Vec2d, Vec3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColStd_Array1OfReal, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> float: ...
	@overload
	@staticmethod
	def D0(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, UIndex: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt2d) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, P: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def D0(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, P: gp_Pnt2d) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColStd_Array1OfReal, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def D1(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt, V: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, UIndex: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt2d, V: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, P: gp_Pnt, V: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, P: gp_Pnt2d, V: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColStd_Array1OfReal, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> Tuple[float, float, float]: ...
	@overload
	@staticmethod
	def D2(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, UIndex: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColStd_Array1OfReal, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> Tuple[float, float, float, float]: ...
	@overload
	@staticmethod
	def D3(U: float, Index: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, UIndex: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@staticmethod
	def Derivative(Degree: int, Dimension: int, Length: int, Order: int) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Eval(U: float, Degree: int, Dimension: int) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Eval(U: float, PeriodicFlag: bool, DerivativeRequest: int, Degree: int, FlatKnots: TColStd_Array1OfReal, ArrayDimension: int) -> Tuple[int, float, float]: ...
	@overload
	@staticmethod
	def Eval(U: float, PeriodicFlag: bool, DerivativeRequest: int, Degree: int, FlatKnots: TColStd_Array1OfReal, ArrayDimension: int) -> Tuple[int, float, float, float, float]: ...
	@overload
	@staticmethod
	def Eval(U: float, PeriodicFlag: bool, HomogeneousFlag: bool, Degree: int, FlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Point: gp_Pnt) -> Tuple[int, float]: ...
	@overload
	@staticmethod
	def Eval(U: float, PeriodicFlag: bool, HomogeneousFlag: bool, Degree: int, FlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Point: gp_Pnt2d) -> Tuple[int, float]: ...
	@staticmethod
	def EvalBsplineBasis(DerivativeOrder: int, Order: int, FlatKnots: TColStd_Array1OfReal, Parameter: float, BsplineBasis: math_Matrix, isPeriodic: Optional[bool] = False) -> Tuple[int, int]: ...
	@staticmethod
	def FactorBandedMatrix(Matrix: math_Matrix, UpperBandWidth: int, LowerBandWidth: int) -> Tuple[int, int]: ...
	@staticmethod
	def FirstUKnotIndex(Degree: int, Mults: TColStd_Array1OfInteger) -> int: ...
	@staticmethod
	def FlatBezierKnots(Degree: int) -> float: ...
	@staticmethod
	def FlatIndex(Degree: int, Index: int, Mults: TColStd_Array1OfInteger, Periodic: bool) -> int: ...
	@overload
	@staticmethod
	def FunctionMultiply(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, PolesDimension: int, FlatKnots: TColStd_Array1OfReal, NewDegree: int) -> Tuple[float, float, int]: ...
	@overload
	@staticmethod
	def FunctionMultiply(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, Poles: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal, NewDegree: int, NewPoles: TColStd_Array1OfReal) -> int: ...
	@overload
	@staticmethod
	def FunctionMultiply(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d, FlatKnots: TColStd_Array1OfReal, NewDegree: int, NewPoles: TColgp_Array1OfPnt2d) -> int: ...
	@overload
	@staticmethod
	def FunctionMultiply(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt, FlatKnots: TColStd_Array1OfReal, NewDegree: int, NewPoles: TColgp_Array1OfPnt) -> int: ...
	@overload
	@staticmethod
	def FunctionReparameterise(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, PolesDimension: int, FlatKnots: TColStd_Array1OfReal, NewDegree: int) -> Tuple[float, float, int]: ...
	@overload
	@staticmethod
	def FunctionReparameterise(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, Poles: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal, NewDegree: int, NewPoles: TColStd_Array1OfReal) -> int: ...
	@overload
	@staticmethod
	def FunctionReparameterise(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt, FlatKnots: TColStd_Array1OfReal, NewDegree: int, NewPoles: TColgp_Array1OfPnt) -> int: ...
	@overload
	@staticmethod
	def FunctionReparameterise(Function: BSplCLib_EvaluatorFunction, BSplineDegree: int, BSplineFlatKnots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d, FlatKnots: TColStd_Array1OfReal, NewDegree: int, NewPoles: TColgp_Array1OfPnt2d) -> int: ...
	@staticmethod
	def GetPole(Index: int, Length: int, Depth: int, Dimension: int, Pole: TColStd_Array1OfReal) -> Tuple[float, int]: ...
	@staticmethod
	def Hunt(theArray: TColStd_Array1OfReal, theX: float) -> int: ...
	@overload
	@staticmethod
	def IncreaseDegree(Degree: int, NewDegree: int, Periodic: bool, Dimension: int, Poles: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger) -> None: ...
	@overload
	@staticmethod
	def IncreaseDegree(Degree: int, NewDegree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger) -> None: ...
	@overload
	@staticmethod
	def IncreaseDegree(Degree: int, NewDegree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger) -> None: ...
	@overload
	@staticmethod
	def IncreaseDegree(NewDegree: int, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def IncreaseDegree(NewDegree: int, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal) -> None: ...
	@staticmethod
	def IncreaseDegreeCountKnots(Degree: int, NewDegree: int, Periodic: bool, Mults: TColStd_Array1OfInteger) -> int: ...
	@overload
	@staticmethod
	def InsertKnot(UIndex: int, U: float, UMult: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def InsertKnot(UIndex: int, U: float, UMult: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def InsertKnots(Degree: int, Periodic: bool, Dimension: int, Poles: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, AddKnots: TColStd_Array1OfReal, AddMults: TColStd_Array1OfInteger, NewPoles: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, Epsilon: float, Add: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def InsertKnots(Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, AddKnots: TColStd_Array1OfReal, AddMults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, Epsilon: float, Add: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def InsertKnots(Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, AddKnots: TColStd_Array1OfReal, AddMults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, Epsilon: float, Add: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def Interpolate(Degree: int, FlatKnots: TColStd_Array1OfReal, Parameters: TColStd_Array1OfReal, ContactOrderArray: TColStd_Array1OfInteger, Poles: TColgp_Array1OfPnt) -> int: ...
	@overload
	@staticmethod
	def Interpolate(Degree: int, FlatKnots: TColStd_Array1OfReal, Parameters: TColStd_Array1OfReal, ContactOrderArray: TColStd_Array1OfInteger, Poles: TColgp_Array1OfPnt2d) -> int: ...
	@overload
	@staticmethod
	def Interpolate(Degree: int, FlatKnots: TColStd_Array1OfReal, Parameters: TColStd_Array1OfReal, ContactOrderArray: TColStd_Array1OfInteger, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal) -> int: ...
	@overload
	@staticmethod
	def Interpolate(Degree: int, FlatKnots: TColStd_Array1OfReal, Parameters: TColStd_Array1OfReal, ContactOrderArray: TColStd_Array1OfInteger, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal) -> int: ...
	@overload
	@staticmethod
	def Interpolate(Degree: int, FlatKnots: TColStd_Array1OfReal, Parameters: TColStd_Array1OfReal, ContactOrderArray: TColStd_Array1OfInteger, ArrayDimension: int) -> Tuple[float, int]: ...
	@overload
	@staticmethod
	def Interpolate(Degree: int, FlatKnots: TColStd_Array1OfReal, Parameters: TColStd_Array1OfReal, ContactOrderArray: TColStd_Array1OfInteger, ArrayDimension: int) -> Tuple[float, float, int]: ...
	@staticmethod
	def IsRational(Weights: TColStd_Array1OfReal, I1: int, I2: int, Epsilon: Optional[float] = 0.0) -> bool: ...
	@staticmethod
	def KnotAnalysis(Degree: int, Periodic: bool, CKnots: TColStd_Array1OfReal, CMults: TColStd_Array1OfInteger, KnotForm: GeomAbs_BSplKnotDistribution) -> int: ...
	@staticmethod
	def KnotForm(Knots: TColStd_Array1OfReal, FromK1: int, ToK2: int) -> BSplCLib_KnotDistribution: ...
	@overload
	@staticmethod
	def KnotSequence(Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, KnotSeq: TColStd_Array1OfReal, Periodic: Optional[bool] = False) -> None: ...
	@overload
	@staticmethod
	def KnotSequence(Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Degree: int, Periodic: bool, KnotSeq: TColStd_Array1OfReal) -> None: ...
	@staticmethod
	def KnotSequenceLength(Mults: TColStd_Array1OfInteger, Degree: int, Periodic: bool) -> int: ...
	@staticmethod
	def Knots(KnotSeq: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Periodic: Optional[bool] = False) -> None: ...
	@staticmethod
	def KnotsLength(KnotSeq: TColStd_Array1OfReal, Periodic: Optional[bool] = False) -> int: ...
	@staticmethod
	def LastUKnotIndex(Degree: int, Mults: TColStd_Array1OfInteger) -> int: ...
	@overload
	@staticmethod
	def LocateParameter(Degree: int, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, U: float, IsPeriodic: bool, FromK1: int, ToK2: int) -> Tuple[int, float]: ...
	@overload
	@staticmethod
	def LocateParameter(Degree: int, Knots: TColStd_Array1OfReal, U: float, IsPeriodic: bool, FromK1: int, ToK2: int) -> Tuple[int, float]: ...
	@overload
	@staticmethod
	def LocateParameter(Degree: int, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, U: float, Periodic: bool) -> Tuple[int, float]: ...
	@staticmethod
	def MaxDegree() -> int: ...
	@staticmethod
	def MaxKnotMult(Mults: TColStd_Array1OfInteger, K1: int, K2: int) -> int: ...
	@staticmethod
	def MergeBSplineKnots(Tolerance: float, StartValue: float, EndValue: float, Degree1: int, Knots1: TColStd_Array1OfReal, Mults1: TColStd_Array1OfInteger, Degree2: int, Knots2: TColStd_Array1OfReal, Mults2: TColStd_Array1OfInteger, NewKnots: TColStd_HArray1OfReal, NewMults: TColStd_HArray1OfInteger) -> int: ...
	@staticmethod
	def MinKnotMult(Mults: TColStd_Array1OfInteger, K1: int, K2: int) -> int: ...
	@overload
	@staticmethod
	def MovePoint(U: float, Displ: gp_Vec2d, Index1: int, Index2: int, Degree: int, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt2d) -> Tuple[int, int]: ...
	@overload
	@staticmethod
	def MovePoint(U: float, Displ: gp_Vec, Index1: int, Index2: int, Degree: int, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt) -> Tuple[int, int]: ...
	@overload
	@staticmethod
	def MovePointAndTangent(U: float, ArrayDimension: int, Tolerance: float, Degree: int, StartingCondition: int, EndingCondition: int, Weights: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal) -> Tuple[float, float, float, float, int]: ...
	@overload
	@staticmethod
	def MovePointAndTangent(U: float, Delta: gp_Vec, DeltaDerivative: gp_Vec, Tolerance: float, Degree: int, StartingCondition: int, EndingCondition: int, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt) -> int: ...
	@overload
	@staticmethod
	def MovePointAndTangent(U: float, Delta: gp_Vec2d, DeltaDerivative: gp_Vec2d, Tolerance: float, Degree: int, StartingCondition: int, EndingCondition: int, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt2d) -> int: ...
	@staticmethod
	def MultForm(Mults: TColStd_Array1OfInteger, FromK1: int, ToK2: int) -> BSplCLib_MultDistribution: ...
	@staticmethod
	def NbPoles(Degree: int, Periodic: bool, Mults: TColStd_Array1OfInteger) -> int: ...
	@staticmethod
	def NoMults() -> TColStd_Array1OfInteger: ...
	@staticmethod
	def NoWeights() -> TColStd_Array1OfReal: ...
	@staticmethod
	def PoleIndex(Degree: int, Index: int, Periodic: bool, Mults: TColStd_Array1OfInteger) -> int: ...
	@overload
	@staticmethod
	def PolesCoefficients(Poles: TColgp_Array1OfPnt2d, CachePoles: TColgp_Array1OfPnt2d) -> None: ...
	@overload
	@staticmethod
	def PolesCoefficients(Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, CachePoles: TColgp_Array1OfPnt2d, CacheWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def PolesCoefficients(Poles: TColgp_Array1OfPnt, CachePoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	@staticmethod
	def PolesCoefficients(Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, CachePoles: TColgp_Array1OfPnt, CacheWeights: TColStd_Array1OfReal) -> None: ...
	@staticmethod
	def PrepareInsertKnots(Degree: int, Periodic: bool, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, AddKnots: TColStd_Array1OfReal, AddMults: TColStd_Array1OfInteger, Epsilon: float, Add: Optional[bool] = True) -> Tuple[bool, int, int]: ...
	@staticmethod
	def PrepareTrimming(Degree: int, Periodic: bool, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, U1: float, U2: float) -> Tuple[int, int]: ...
	@staticmethod
	def PrepareUnperiodize(Degree: int, Mults: TColStd_Array1OfInteger) -> Tuple[int, int]: ...
	@overload
	@staticmethod
	def RaiseMultiplicity(KnotIndex: int, Mult: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def RaiseMultiplicity(KnotIndex: int, Mult: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def RemoveKnot(Index: int, Mult: int, Degree: int, Periodic: bool, Dimension: int, Poles: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, Tolerance: float) -> bool: ...
	@overload
	@staticmethod
	def RemoveKnot(Index: int, Mult: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, Tolerance: float) -> bool: ...
	@overload
	@staticmethod
	def RemoveKnot(Index: int, Mult: int, Degree: int, Periodic: bool, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, Tolerance: float) -> bool: ...
	@staticmethod
	def Reparametrize(U1: float, U2: float, Knots: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Resolution(ArrayDimension: int, NumPoles: int, Weights: TColStd_Array1OfReal, FlatKnots: TColStd_Array1OfReal, Degree: int, Tolerance3D: float) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Resolution(Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, NumPoles: int, FlatKnots: TColStd_Array1OfReal, Degree: int, Tolerance3D: float) -> float: ...
	@overload
	@staticmethod
	def Resolution(Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, NumPoles: int, FlatKnots: TColStd_Array1OfReal, Degree: int, Tolerance3D: float) -> float: ...
	@overload
	@staticmethod
	def Reverse(Knots: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Reverse(Mults: TColStd_Array1OfInteger) -> None: ...
	@overload
	@staticmethod
	def Reverse(Poles: TColgp_Array1OfPnt, Last: int) -> None: ...
	@overload
	@staticmethod
	def Reverse(Poles: TColgp_Array1OfPnt2d, Last: int) -> None: ...
	@overload
	@staticmethod
	def Reverse(Weights: TColStd_Array1OfReal, Last: int) -> None: ...
	@overload
	@staticmethod
	def SolveBandedSystem(Matrix: math_Matrix, UpperBandWidth: int, LowerBandWidth: int, ArrayDimension: int) -> Tuple[int, float]: ...
	@overload
	@staticmethod
	def SolveBandedSystem(Matrix: math_Matrix, UpperBandWidth: int, LowerBandWidth: int, Array: TColgp_Array1OfPnt2d) -> int: ...
	@overload
	@staticmethod
	def SolveBandedSystem(Matrix: math_Matrix, UpperBandWidth: int, LowerBandWidth: int, Array: TColgp_Array1OfPnt) -> int: ...
	@overload
	@staticmethod
	def SolveBandedSystem(Matrix: math_Matrix, UpperBandWidth: int, LowerBandWidth: int, HomogenousFlag: bool, ArrayDimension: int) -> Tuple[int, float, float]: ...
	@overload
	@staticmethod
	def SolveBandedSystem(Matrix: math_Matrix, UpperBandWidth: int, LowerBandWidth: int, HomogenousFlag: bool, Array: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal) -> int: ...
	@overload
	@staticmethod
	def SolveBandedSystem(Matrix: math_Matrix, UpperBandWidth: int, LowerBandWidth: int, HomogeneousFlag: bool, Array: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal) -> int: ...
	@staticmethod
	def TangExtendToConstraint(FlatKnots: TColStd_Array1OfReal, C1Coefficient: float, NumPoles: int, Dimension: int, Degree: int, ConstraintPoint: TColStd_Array1OfReal, Continuity: int, After: bool) -> Tuple[float, int, int, float, float]: ...
	@overload
	@staticmethod
	def Trimming(Degree: int, Periodic: bool, Dimension: int, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Poles: TColStd_Array1OfReal, U1: float, U2: float, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, NewPoles: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Trimming(Degree: int, Periodic: bool, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, U1: float, U2: float, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Trimming(Degree: int, Periodic: bool, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, U1: float, U2: float, NewKnots: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Unperiodize(Degree: int, Dimension: int, Mults: TColStd_Array1OfInteger, Knots: TColStd_Array1OfReal, Poles: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, NewKnots: TColStd_Array1OfReal, NewPoles: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Unperiodize(Degree: int, Mults: TColStd_Array1OfInteger, Knots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, NewKnots: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt, NewWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	@staticmethod
	def Unperiodize(Degree: int, Mults: TColStd_Array1OfInteger, Knots: TColStd_Array1OfReal, Poles: TColgp_Array1OfPnt2d, Weights: TColStd_Array1OfReal, NewMults: TColStd_Array1OfInteger, NewKnots: TColStd_Array1OfReal, NewPoles: TColgp_Array1OfPnt2d, NewWeights: TColStd_Array1OfReal) -> None: ...

class BSplCLib_Cache(Standard_Transient):
	@overload
	def __init__(self, theDegree: int, thePeriodic: bool, theFlatKnots: TColStd_Array1OfReal, thePoles2d: TColgp_Array1OfPnt2d, theWeights: Optional[TColStd_Array1OfReal] = None) -> None: ...
	@overload
	def __init__(self, theDegree: int, thePeriodic: bool, theFlatKnots: TColStd_Array1OfReal, thePoles: TColgp_Array1OfPnt, theWeights: Optional[TColStd_Array1OfReal] = None) -> None: ...
	@overload
	def BuildCache(self, theParameter: float, theFlatKnots: TColStd_Array1OfReal, thePoles2d: TColgp_Array1OfPnt2d, theWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	def BuildCache(self, theParameter: float, theFlatKnots: TColStd_Array1OfReal, thePoles: TColgp_Array1OfPnt, theWeights: Optional[TColStd_Array1OfReal] = None) -> None: ...
	@overload
	def D0(self, theParameter: float, thePoint: gp_Pnt2d) -> None: ...
	@overload
	def D0(self, theParameter: float, thePoint: gp_Pnt) -> None: ...
	@overload
	def D1(self, theParameter: float, thePoint: gp_Pnt2d, theTangent: gp_Vec2d) -> None: ...
	@overload
	def D1(self, theParameter: float, thePoint: gp_Pnt, theTangent: gp_Vec) -> None: ...
	@overload
	def D2(self, theParameter: float, thePoint: gp_Pnt2d, theTangent: gp_Vec2d, theCurvature: gp_Vec2d) -> None: ...
	@overload
	def D2(self, theParameter: float, thePoint: gp_Pnt, theTangent: gp_Vec, theCurvature: gp_Vec) -> None: ...
	@overload
	def D3(self, theParameter: float, thePoint: gp_Pnt2d, theTangent: gp_Vec2d, theCurvature: gp_Vec2d, theTorsion: gp_Vec2d) -> None: ...
	@overload
	def D3(self, theParameter: float, thePoint: gp_Pnt, theTangent: gp_Vec, theCurvature: gp_Vec, theTorsion: gp_Vec) -> None: ...
	def IsCacheValid(self, theParameter: float) -> bool: ...

class BSplCLib_CacheParams:
	def __init__(self, theDegree: int, thePeriodic: bool, theFlatKnots: TColStd_Array1OfReal) -> None: ...
	def IsCacheValid(self, theParameter: float) -> bool: ...
	def LocateParameter(self, theFlatKnots: TColStd_Array1OfReal) -> float: ...
	def PeriodicNormalization(self, theParameter: float) -> float: ...

class BSplCLib_EvaluatorFunction:
	def Evaluate(self, theDerivativeRequest: int, theStartEnd: float, theParameter: float) -> Tuple[float, int]: ...

# harray1 classes
# harray2 classes
# hsequence classes

bsplclib_AntiBoorScheme = bsplclib.AntiBoorScheme
bsplclib_Bohm = bsplclib.Bohm
bsplclib_BoorIndex = bsplclib.BoorIndex
bsplclib_BoorScheme = bsplclib.BoorScheme
bsplclib_BuildBSpMatrix = bsplclib.BuildBSpMatrix
bsplclib_BuildBoor = bsplclib.BuildBoor
bsplclib_BuildCache = bsplclib.BuildCache
bsplclib_BuildCache = bsplclib.BuildCache
bsplclib_BuildCache = bsplclib.BuildCache
bsplclib_BuildCache = bsplclib.BuildCache
bsplclib_BuildEval = bsplclib.BuildEval
bsplclib_BuildEval = bsplclib.BuildEval
bsplclib_BuildEval = bsplclib.BuildEval
bsplclib_BuildKnots = bsplclib.BuildKnots
bsplclib_BuildSchoenbergPoints = bsplclib.BuildSchoenbergPoints
bsplclib_CacheD0 = bsplclib.CacheD0
bsplclib_CacheD0 = bsplclib.CacheD0
bsplclib_CacheD1 = bsplclib.CacheD1
bsplclib_CacheD1 = bsplclib.CacheD1
bsplclib_CacheD2 = bsplclib.CacheD2
bsplclib_CacheD2 = bsplclib.CacheD2
bsplclib_CacheD3 = bsplclib.CacheD3
bsplclib_CacheD3 = bsplclib.CacheD3
bsplclib_CoefsD0 = bsplclib.CoefsD0
bsplclib_CoefsD0 = bsplclib.CoefsD0
bsplclib_CoefsD1 = bsplclib.CoefsD1
bsplclib_CoefsD1 = bsplclib.CoefsD1
bsplclib_CoefsD2 = bsplclib.CoefsD2
bsplclib_CoefsD2 = bsplclib.CoefsD2
bsplclib_CoefsD3 = bsplclib.CoefsD3
bsplclib_CoefsD3 = bsplclib.CoefsD3
bsplclib_D0 = bsplclib.D0
bsplclib_D0 = bsplclib.D0
bsplclib_D0 = bsplclib.D0
bsplclib_D0 = bsplclib.D0
bsplclib_D0 = bsplclib.D0
bsplclib_D1 = bsplclib.D1
bsplclib_D1 = bsplclib.D1
bsplclib_D1 = bsplclib.D1
bsplclib_D1 = bsplclib.D1
bsplclib_D1 = bsplclib.D1
bsplclib_D2 = bsplclib.D2
bsplclib_D2 = bsplclib.D2
bsplclib_D2 = bsplclib.D2
bsplclib_D2 = bsplclib.D2
bsplclib_D2 = bsplclib.D2
bsplclib_D3 = bsplclib.D3
bsplclib_D3 = bsplclib.D3
bsplclib_D3 = bsplclib.D3
bsplclib_D3 = bsplclib.D3
bsplclib_D3 = bsplclib.D3
bsplclib_Derivative = bsplclib.Derivative
bsplclib_Eval = bsplclib.Eval
bsplclib_Eval = bsplclib.Eval
bsplclib_Eval = bsplclib.Eval
bsplclib_Eval = bsplclib.Eval
bsplclib_Eval = bsplclib.Eval
bsplclib_EvalBsplineBasis = bsplclib.EvalBsplineBasis
bsplclib_FactorBandedMatrix = bsplclib.FactorBandedMatrix
bsplclib_FirstUKnotIndex = bsplclib.FirstUKnotIndex
bsplclib_FlatBezierKnots = bsplclib.FlatBezierKnots
bsplclib_FlatIndex = bsplclib.FlatIndex
bsplclib_FunctionMultiply = bsplclib.FunctionMultiply
bsplclib_FunctionMultiply = bsplclib.FunctionMultiply
bsplclib_FunctionMultiply = bsplclib.FunctionMultiply
bsplclib_FunctionMultiply = bsplclib.FunctionMultiply
bsplclib_FunctionReparameterise = bsplclib.FunctionReparameterise
bsplclib_FunctionReparameterise = bsplclib.FunctionReparameterise
bsplclib_FunctionReparameterise = bsplclib.FunctionReparameterise
bsplclib_FunctionReparameterise = bsplclib.FunctionReparameterise
bsplclib_GetPole = bsplclib.GetPole
bsplclib_Hunt = bsplclib.Hunt
bsplclib_IncreaseDegree = bsplclib.IncreaseDegree
bsplclib_IncreaseDegree = bsplclib.IncreaseDegree
bsplclib_IncreaseDegree = bsplclib.IncreaseDegree
bsplclib_IncreaseDegree = bsplclib.IncreaseDegree
bsplclib_IncreaseDegree = bsplclib.IncreaseDegree
bsplclib_IncreaseDegreeCountKnots = bsplclib.IncreaseDegreeCountKnots
bsplclib_InsertKnot = bsplclib.InsertKnot
bsplclib_InsertKnot = bsplclib.InsertKnot
bsplclib_InsertKnots = bsplclib.InsertKnots
bsplclib_InsertKnots = bsplclib.InsertKnots
bsplclib_InsertKnots = bsplclib.InsertKnots
bsplclib_Interpolate = bsplclib.Interpolate
bsplclib_Interpolate = bsplclib.Interpolate
bsplclib_Interpolate = bsplclib.Interpolate
bsplclib_Interpolate = bsplclib.Interpolate
bsplclib_Interpolate = bsplclib.Interpolate
bsplclib_Interpolate = bsplclib.Interpolate
bsplclib_IsRational = bsplclib.IsRational
bsplclib_KnotAnalysis = bsplclib.KnotAnalysis
bsplclib_KnotForm = bsplclib.KnotForm
bsplclib_KnotSequence = bsplclib.KnotSequence
bsplclib_KnotSequence = bsplclib.KnotSequence
bsplclib_KnotSequenceLength = bsplclib.KnotSequenceLength
bsplclib_Knots = bsplclib.Knots
bsplclib_KnotsLength = bsplclib.KnotsLength
bsplclib_LastUKnotIndex = bsplclib.LastUKnotIndex
bsplclib_LocateParameter = bsplclib.LocateParameter
bsplclib_LocateParameter = bsplclib.LocateParameter
bsplclib_LocateParameter = bsplclib.LocateParameter
bsplclib_MaxDegree = bsplclib.MaxDegree
bsplclib_MaxKnotMult = bsplclib.MaxKnotMult
bsplclib_MergeBSplineKnots = bsplclib.MergeBSplineKnots
bsplclib_MinKnotMult = bsplclib.MinKnotMult
bsplclib_MovePoint = bsplclib.MovePoint
bsplclib_MovePoint = bsplclib.MovePoint
bsplclib_MovePointAndTangent = bsplclib.MovePointAndTangent
bsplclib_MovePointAndTangent = bsplclib.MovePointAndTangent
bsplclib_MovePointAndTangent = bsplclib.MovePointAndTangent
bsplclib_MultForm = bsplclib.MultForm
bsplclib_NbPoles = bsplclib.NbPoles
bsplclib_NoMults = bsplclib.NoMults
bsplclib_NoWeights = bsplclib.NoWeights
bsplclib_PoleIndex = bsplclib.PoleIndex
bsplclib_PolesCoefficients = bsplclib.PolesCoefficients
bsplclib_PolesCoefficients = bsplclib.PolesCoefficients
bsplclib_PolesCoefficients = bsplclib.PolesCoefficients
bsplclib_PolesCoefficients = bsplclib.PolesCoefficients
bsplclib_PrepareInsertKnots = bsplclib.PrepareInsertKnots
bsplclib_PrepareTrimming = bsplclib.PrepareTrimming
bsplclib_PrepareUnperiodize = bsplclib.PrepareUnperiodize
bsplclib_RaiseMultiplicity = bsplclib.RaiseMultiplicity
bsplclib_RaiseMultiplicity = bsplclib.RaiseMultiplicity
bsplclib_RemoveKnot = bsplclib.RemoveKnot
bsplclib_RemoveKnot = bsplclib.RemoveKnot
bsplclib_RemoveKnot = bsplclib.RemoveKnot
bsplclib_Reparametrize = bsplclib.Reparametrize
bsplclib_Resolution = bsplclib.Resolution
bsplclib_Resolution = bsplclib.Resolution
bsplclib_Resolution = bsplclib.Resolution
bsplclib_Reverse = bsplclib.Reverse
bsplclib_Reverse = bsplclib.Reverse
bsplclib_Reverse = bsplclib.Reverse
bsplclib_Reverse = bsplclib.Reverse
bsplclib_Reverse = bsplclib.Reverse
bsplclib_SolveBandedSystem = bsplclib.SolveBandedSystem
bsplclib_SolveBandedSystem = bsplclib.SolveBandedSystem
bsplclib_SolveBandedSystem = bsplclib.SolveBandedSystem
bsplclib_SolveBandedSystem = bsplclib.SolveBandedSystem
bsplclib_SolveBandedSystem = bsplclib.SolveBandedSystem
bsplclib_SolveBandedSystem = bsplclib.SolveBandedSystem
bsplclib_TangExtendToConstraint = bsplclib.TangExtendToConstraint
bsplclib_Trimming = bsplclib.Trimming
bsplclib_Trimming = bsplclib.Trimming
bsplclib_Trimming = bsplclib.Trimming
bsplclib_Unperiodize = bsplclib.Unperiodize
bsplclib_Unperiodize = bsplclib.Unperiodize
bsplclib_Unperiodize = bsplclib.Unperiodize



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepGeom import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *


class steptogeom:
	@staticmethod
	def MakeAxis1Placement(SA: StepGeom_Axis1Placement) -> Geom_Axis1Placement: ...
	@staticmethod
	def MakeAxis2Placement(SA: StepGeom_Axis2Placement3d) -> Geom_Axis2Placement: ...
	@staticmethod
	def MakeAxisPlacement(SA: StepGeom_Axis2Placement2d) -> Geom2d_AxisPlacement: ...
	@staticmethod
	def MakeBSplineCurve(SC: StepGeom_BSplineCurve) -> Geom_BSplineCurve: ...
	@staticmethod
	def MakeBSplineCurve2d(SC: StepGeom_BSplineCurve) -> Geom2d_BSplineCurve: ...
	@staticmethod
	def MakeBSplineSurface(SS: StepGeom_BSplineSurface) -> Geom_BSplineSurface: ...
	@staticmethod
	def MakeBoundedCurve(SC: StepGeom_BoundedCurve) -> Geom_BoundedCurve: ...
	@staticmethod
	def MakeBoundedCurve2d(SC: StepGeom_BoundedCurve) -> Geom2d_BoundedCurve: ...
	@staticmethod
	def MakeBoundedSurface(SS: StepGeom_BoundedSurface) -> Geom_BoundedSurface: ...
	@staticmethod
	def MakeCartesianPoint(SP: StepGeom_CartesianPoint) -> Geom_CartesianPoint: ...
	@staticmethod
	def MakeCartesianPoint2d(SP: StepGeom_CartesianPoint) -> Geom2d_CartesianPoint: ...
	@staticmethod
	def MakeCircle(SC: StepGeom_Circle) -> Geom_Circle: ...
	@staticmethod
	def MakeCircle2d(SC: StepGeom_Circle) -> Geom2d_Circle: ...
	@staticmethod
	def MakeConic(SC: StepGeom_Conic) -> Geom_Conic: ...
	@staticmethod
	def MakeConic2d(SC: StepGeom_Conic) -> Geom2d_Conic: ...
	@staticmethod
	def MakeConicalSurface(SS: StepGeom_ConicalSurface) -> Geom_ConicalSurface: ...
	@staticmethod
	def MakeCurve(SC: StepGeom_Curve) -> Geom_Curve: ...
	@staticmethod
	def MakeCurve2d(SC: StepGeom_Curve) -> Geom2d_Curve: ...
	@staticmethod
	def MakeCylindricalSurface(SS: StepGeom_CylindricalSurface) -> Geom_CylindricalSurface: ...
	@staticmethod
	def MakeDirection(SD: StepGeom_Direction) -> Geom_Direction: ...
	@staticmethod
	def MakeDirection2d(SD: StepGeom_Direction) -> Geom2d_Direction: ...
	@staticmethod
	def MakeElementarySurface(SS: StepGeom_ElementarySurface) -> Geom_ElementarySurface: ...
	@staticmethod
	def MakeEllipse(SC: StepGeom_Ellipse) -> Geom_Ellipse: ...
	@staticmethod
	def MakeEllipse2d(SC: StepGeom_Ellipse) -> Geom2d_Ellipse: ...
	@staticmethod
	def MakeHyperbola(SC: StepGeom_Hyperbola) -> Geom_Hyperbola: ...
	@staticmethod
	def MakeHyperbola2d(SC: StepGeom_Hyperbola) -> Geom2d_Hyperbola: ...
	@staticmethod
	def MakeLine(SC: StepGeom_Line) -> Geom_Line: ...
	@staticmethod
	def MakeLine2d(SC: StepGeom_Line) -> Geom2d_Line: ...
	@staticmethod
	def MakeParabola(SC: StepGeom_Parabola) -> Geom_Parabola: ...
	@staticmethod
	def MakeParabola2d(SC: StepGeom_Parabola) -> Geom2d_Parabola: ...
	@staticmethod
	def MakePlane(SP: StepGeom_Plane) -> Geom_Plane: ...
	@staticmethod
	def MakePolyline(SPL: StepGeom_Polyline) -> Geom_BSplineCurve: ...
	@staticmethod
	def MakePolyline2d(SPL: StepGeom_Polyline) -> Geom2d_BSplineCurve: ...
	@staticmethod
	def MakeRectangularTrimmedSurface(SS: StepGeom_RectangularTrimmedSurface) -> Geom_RectangularTrimmedSurface: ...
	@staticmethod
	def MakeSphericalSurface(SS: StepGeom_SphericalSurface) -> Geom_SphericalSurface: ...
	@staticmethod
	def MakeSurface(SS: StepGeom_Surface) -> Geom_Surface: ...
	@staticmethod
	def MakeSurfaceOfLinearExtrusion(SS: StepGeom_SurfaceOfLinearExtrusion) -> Geom_SurfaceOfLinearExtrusion: ...
	@staticmethod
	def MakeSurfaceOfRevolution(SS: StepGeom_SurfaceOfRevolution) -> Geom_SurfaceOfRevolution: ...
	@staticmethod
	def MakeSweptSurface(SS: StepGeom_SweptSurface) -> Geom_SweptSurface: ...
	@staticmethod
	def MakeToroidalSurface(SS: StepGeom_ToroidalSurface) -> Geom_ToroidalSurface: ...
	@staticmethod
	def MakeTransformation2d(SCTO: StepGeom_CartesianTransformationOperator2d, CT: gp_Trsf2d) -> bool: ...
	@staticmethod
	def MakeTransformation3d(SCTO: StepGeom_CartesianTransformationOperator3d, CT: gp_Trsf) -> bool: ...
	@staticmethod
	def MakeTrimmedCurve(SC: StepGeom_TrimmedCurve) -> Geom_TrimmedCurve: ...
	@staticmethod
	def MakeTrimmedCurve2d(SC: StepGeom_TrimmedCurve) -> Geom2d_BSplineCurve: ...
	@staticmethod
	def MakeVectorWithMagnitude(SV: StepGeom_Vector) -> Geom_VectorWithMagnitude: ...
	@staticmethod
	def MakeVectorWithMagnitude2d(SV: StepGeom_Vector) -> Geom2d_VectorWithMagnitude: ...

# harray1 classes
# harray2 classes
# hsequence classes

steptogeom_MakeAxis1Placement = steptogeom.MakeAxis1Placement
steptogeom_MakeAxis2Placement = steptogeom.MakeAxis2Placement
steptogeom_MakeAxisPlacement = steptogeom.MakeAxisPlacement
steptogeom_MakeBSplineCurve = steptogeom.MakeBSplineCurve
steptogeom_MakeBSplineCurve2d = steptogeom.MakeBSplineCurve2d
steptogeom_MakeBSplineSurface = steptogeom.MakeBSplineSurface
steptogeom_MakeBoundedCurve = steptogeom.MakeBoundedCurve
steptogeom_MakeBoundedCurve2d = steptogeom.MakeBoundedCurve2d
steptogeom_MakeBoundedSurface = steptogeom.MakeBoundedSurface
steptogeom_MakeCartesianPoint = steptogeom.MakeCartesianPoint
steptogeom_MakeCartesianPoint2d = steptogeom.MakeCartesianPoint2d
steptogeom_MakeCircle = steptogeom.MakeCircle
steptogeom_MakeCircle2d = steptogeom.MakeCircle2d
steptogeom_MakeConic = steptogeom.MakeConic
steptogeom_MakeConic2d = steptogeom.MakeConic2d
steptogeom_MakeConicalSurface = steptogeom.MakeConicalSurface
steptogeom_MakeCurve = steptogeom.MakeCurve
steptogeom_MakeCurve2d = steptogeom.MakeCurve2d
steptogeom_MakeCylindricalSurface = steptogeom.MakeCylindricalSurface
steptogeom_MakeDirection = steptogeom.MakeDirection
steptogeom_MakeDirection2d = steptogeom.MakeDirection2d
steptogeom_MakeElementarySurface = steptogeom.MakeElementarySurface
steptogeom_MakeEllipse = steptogeom.MakeEllipse
steptogeom_MakeEllipse2d = steptogeom.MakeEllipse2d
steptogeom_MakeHyperbola = steptogeom.MakeHyperbola
steptogeom_MakeHyperbola2d = steptogeom.MakeHyperbola2d
steptogeom_MakeLine = steptogeom.MakeLine
steptogeom_MakeLine2d = steptogeom.MakeLine2d
steptogeom_MakeParabola = steptogeom.MakeParabola
steptogeom_MakeParabola2d = steptogeom.MakeParabola2d
steptogeom_MakePlane = steptogeom.MakePlane
steptogeom_MakePolyline = steptogeom.MakePolyline
steptogeom_MakePolyline2d = steptogeom.MakePolyline2d
steptogeom_MakeRectangularTrimmedSurface = steptogeom.MakeRectangularTrimmedSurface
steptogeom_MakeSphericalSurface = steptogeom.MakeSphericalSurface
steptogeom_MakeSurface = steptogeom.MakeSurface
steptogeom_MakeSurfaceOfLinearExtrusion = steptogeom.MakeSurfaceOfLinearExtrusion
steptogeom_MakeSurfaceOfRevolution = steptogeom.MakeSurfaceOfRevolution
steptogeom_MakeSweptSurface = steptogeom.MakeSweptSurface
steptogeom_MakeToroidalSurface = steptogeom.MakeToroidalSurface
steptogeom_MakeTransformation2d = steptogeom.MakeTransformation2d
steptogeom_MakeTransformation3d = steptogeom.MakeTransformation3d
steptogeom_MakeTrimmedCurve = steptogeom.MakeTrimmedCurve
steptogeom_MakeTrimmedCurve2d = steptogeom.MakeTrimmedCurve2d
steptogeom_MakeVectorWithMagnitude = steptogeom.MakeVectorWithMagnitude
steptogeom_MakeVectorWithMagnitude2d = steptogeom.MakeVectorWithMagnitude2d
